@@ -1,4 +1,4 @@
-import pandas as pd
+import pandas as pd  # pyright: ignore[reportMissingImports]
 
 from redframes.types import PandasDataFrame
 
